﻿using System;
using System.ComponentModel;
using System.Runtime.InteropServices;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls.WebParts;
using TechFest.SharePoint.JQuery.Utilities;

namespace TechFest.SharePoint.JQuery
{
    /// <summary>
    /// EqualHeightWebPart compares the height of web parts which have the same sort index across multiple web part zones and makes them equal.
    /// </summary>
    [Guid("eedb4e18-c2d0-4664-a87a-dc5040209b9b")]
	public class EqualHeightWebPart : System.Web.UI.WebControls.WebParts.WebPart
	{
		#region Properties
	
		/// <summary>
		/// The jQuery selector which selects the web part zones to compare.
		/// </summary>
		[Personalizable(PersonalizationScope.Shared),
		WebBrowsable(true),
		WebDisplayName("jQuery Selector"),
		WebDescription("Enter the jQuery selector which selects the web part zones to compare."),
		Category("Configuration")]
		public string jQuerySelectorText
		{
			get;
			set;
		}

		#endregion


		protected override void CreateChildControls()
		{
			// if we're not in browse mode, display the web part about message instead of registering and running scripts
			if (WebPartManager.DisplayMode != WebPartManager.BrowseDisplayMode)
			{
				HtmlGenericControl editModeMsg = new HtmlGenericControl("p");
				editModeMsg.InnerText = "This web part compares the height of web parts which have the same sort index across multiple web part zones and makes them equal.";
				this.Controls.Add(editModeMsg);
			}
			else
			{
                RegisterClientSideArtifacts();
			}
		}


        /// <summary>
        /// Registers client-side artifacts such as JavaScript and CSS links and inline blocks
        /// </summary>
        private void RegisterClientSideArtifacts()
		{
			this.Hidden = true;
			this.CssClass = "devteach-EqualHeightWebPart";

			if (!string.IsNullOrEmpty(this.jQuerySelectorText))
			{
                ClientScriptManager csMgr = this.Page.ClientScript;

                string appPath = (this.Page.Request.ApplicationPath == "/" ? "" : this.Page.Request.ApplicationPath);

                // register jQuery script library
                ClientSideHelpers.RegisterClientScriptInclude(
                    this, ClientSideArtifacts.JQueryScriptKey,
                    string.Format("{0}{1}", appPath, ClientSideArtifacts.JQueryScriptFile)
                );

                // register EqualHeightWebPart script library
                ClientSideHelpers.RegisterClientScriptInclude(
                    this, ClientSideArtifacts.EqualHeightWebPartScriptKey,
                    string.Format("{0}{1}", appPath, ClientSideArtifacts.EqualHeightWebPartScriptFile)
                );

                // inline script block to invoke the tab switcher
                string initScript = string.Format(
                    "\n$(document).ready(function() {{\n$('{0}').EqualHeightWebPart();\n}});\n",
                    this.jQuerySelectorText
                );

                // register inline script block
                ClientSideHelpers.RegisterStartupScript(
                    this, ClientSideArtifacts.EqualHeightWebPartScriptKey, initScript
                );
            }
		}
	
    }
}
