﻿using System;
using System.ComponentModel;
using System.Runtime.InteropServices;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls.WebParts;
using TechFest.SharePoint.JQuery.Utilities;

namespace TechFest.SharePoint.JQuery
{
    /// <summary>
    /// TabSwitcherWebPart creates a tabbed content switcher interface for all other web parts in the same web part zone.
    /// </summary>
    [Guid("4cf97925-292b-4d45-8704-1c4d425031a2")]
    public class TabSwitcherWebPart : System.Web.UI.WebControls.WebParts.WebPart
    {
        #region Properties

        /// <summary>
        /// Gets or sets the HTML class attribute for the tab switcher container element
        /// </summary>
        [Personalizable(PersonalizationScope.Shared),
        WebBrowsable(true),
        WebDisplayName("HTML Class"),
        WebDescription("Enter the HTML class attribute for the tab switcher container element."),
        Category("Configuration")]
        public string HtmlClass
        {
            get;
            set;
        }

        #endregion


        protected override void CreateChildControls()
        {
            base.CreateChildControls();
					
            // if we're not in browse mode, display the web part about message
            // instead of registering and running scripts
            if (WebPartManager.DisplayMode != WebPartManager.BrowseDisplayMode)
            {
                HtmlGenericControl editModeMsg = new HtmlGenericControl("p");
                editModeMsg.InnerText = "This web part creates a tabbed content switcher interface for all other web parts in the same web part zone.";
                this.Controls.Add(editModeMsg);
            }
            else
            {
                this.CssClass = "tf-TabSwitcherWebPart-WebPart";
                RegisterClientSideArtifacts();
            }
        }


        /// <summary>
        /// Registers client-side artifacts such as JavaScript and CSS links and inline blocks
        /// </summary>
        private void RegisterClientSideArtifacts()
        {
            ClientScriptManager csMgr = this.Page.ClientScript;

            string appPath = (this.Page.Request.ApplicationPath == "/" ? "" : this.Page.Request.ApplicationPath);

            // register TabSwitcherWebPart CSS
            ClientSideHelpers.RegisterCssLink(
                this, ClientSideArtifacts.TabSwitcherWebPartCssKey,
                string.Format("{0}{1}", appPath, ClientSideArtifacts.TabSwitcherWebPartCssFile)
            );

            // register jQuery script library
            ClientSideHelpers.RegisterClientScriptInclude(
                this, ClientSideArtifacts.JQueryScriptKey,
                string.Format("{0}{1}", appPath, ClientSideArtifacts.JQueryScriptFile)
            );

            // register TabSwitcherWebPart script library
            ClientSideHelpers.RegisterClientScriptInclude(
                this, ClientSideArtifacts.TabSwitcherWebPartScriptKey,
                string.Format("{0}{1}", appPath, ClientSideArtifacts.TabSwitcherWebPartScriptFile)
            );

            // inline script block to invoke the tab switcher
            string initScript = string.Format(
                "\n$(document).ready(function() {{\n$('#{0}').TabSwitcherWebPart({1});\n}});\n",
                this.ClientID,
                (!string.IsNullOrEmpty(this.HtmlClass) ? "{HtmlClass:'" + this.HtmlClass + "'}" : "")
            );

            // register inline script block
            ClientSideHelpers.RegisterStartupScript(
                this, ClientSideArtifacts.TabSwitcherWebPartScriptKey, initScript
            );
        }

    }
}
