﻿/// <reference path="../jquery-1.3.2-vsdoc2.js" />

(function($) {

    /// <summary>
    /// EqualHeightWebPart compares the height of web parts which have the same sort index across multiple web part zones and makes them equal.
    /// </summary>
    $.fn.EqualHeightWebPart = function(options) {

        // build main options before element iteration
        var opts = $.extend({}, $.fn.EqualHeightWebPart.defaults, options);

        opts.columns = new Array();
        opts.longestColumnIndex;
        opts.resizeTimer = null;

        // remove all equal height web part rows from page
        $('.tf-EqualHeightWebPart', this).parent().parent().parent().parent().parent().parent().parent().remove();

        // iterate through the element collection.
        this.each(function(index, column) {
            var $column = $(column);
            var webparts = new Array();

            // build element specific options, compatible with Metadata Plugin
            // http://plugins.jquery.com/project/metadata
            var o = $.meta ? $.extend({}, opts, $this.data()) : opts;

            var $webparts = $("div[id*='WebPartWPQ']", $column);

            // get the parent table element of each web part
            $webparts.each(function(i) {
                var $this = $(this);

                webparts[i] = $this.parent().parent().parent().parent();
            });

            if (webparts.length > 0) {
                opts.columns.push(webparts);
            }

            if ($webparts.length > 0) {
                opts.longestColumnIndex = opts.columns.length - 1;
            }
        });

        // bind event handling to resize web parts on browser window resize
        $(window).bind('resize', function() {
            if (opts.resizeTimer) clearTimeout(opts.resizeTimer);
            opts.resizeTimer = setTimeout(function() {
                $.fn.EqualHeightWebPart.ResizeWebParts(opts);
            }, 50);
        });

        // resize web parts now
        $.fn.EqualHeightWebPart.ResizeWebParts(opts);

        // must return jQuery collection
        return (this);
    };



    /// <summary>resize web part height</summary>
    /// <param name="opts">internal options</param>
    $.fn.EqualHeightWebPart.ResizeWebParts = function(opts) {
        if (opts.columns.length > 1) {
            for (var i = 0; i < opts.columns[opts.longestColumnIndex].length; i++) {
                // tallest web part height per row
                var rowH = getTallestHeight(opts.columns, i);

                setWebPartHeight(rowH, opts.columns, i);
            }
        }
    };


    /// <summary>get the tallest webpart's height in each "row"</summary>
    /// <param name="height">int; height of the tallest webpart</param>
    /// <param name="columns">array; web part zone "columns"</param>
    /// <param name="rowIndex">int; index of web parts to target</param>
    /// <returns>int</returns>
    function getTallestHeight(columns, rowIndex) {
        var h = 0;

        for (var i = 0; i < columns.length; i++) {
            var $wp = columns[i][rowIndex];

            if ($wp) {
                if ($wp.length > 0) {
                    var $wpheader = $('.ms-WPHeader', $wp);
                    var $wpbody = $("div[id*='WebPartWPQ']", $wp).height('auto');

                    if ($wpbody.length > 0) {
                        var wp_h = $wpbody.outerHeight() + ($wpheader.length > 0 ? $wpheader.outerHeight(true) : 0);

                        if (h < wp_h) {
                            h = wp_h;
                        }
                    }
                }
            }
        }

        return h;
    };


    /// <summary>set the height for web parts in each "row"</summary>
    /// <param name="height">int; height of the tallest webpart</param>
    /// <param name="columns">array; web part zone "columns"</param>
    /// <param name="rowIndex">int; index of web parts to target</param>
    /// <returns>void</returns>
    function setWebPartHeight(height, columns, rowIndex) {
        for (var i = 0; i < columns.length; i++) {
            var $wp = columns[i][rowIndex];

            if ($wp) {
                if ($wp.length > 0) {
                    var $wpheader = $('.ms-WPHeader', $wp);
                    var $wpbody = $("div[id*='WebPartWPQ']", $wp);

                    if ($wpbody.length > 0) {
                        var wpheader_h = ($wpheader.length > 0 ? $wpheader.outerHeight(true) : 0);

                        //web part body's height should be web part height - header height - web part body's padding
                        $wpbody.height(height - wpheader_h - ($wpbody.outerHeight() - $wpbody.height()));
                    }
                }
            }
        }
    };


    // set any default options here.
    $.fn.EqualHeightWebPart.defaults = {
};
})(jQuery);
