﻿/// <reference path="../Common/jquery-1.3.2-vsdoc2.js" />

(function($) {
    /* ------------------------------------------------------

	plugin definition

	------------------------------------------------------ */

    /// <summary>
    /// TabSwitcherWebPart creates a tabbed content switcher interface for
    /// all other web parts in the same web part zone.
    /// </summary>
    $.fn.TabSwitcherWebPart = function(options) {
        // build main options before element iteration
        var opts = $.extend({}, $.fn.TabSwitcherWebPart.defaults, options);

        // Returns the element collection. Chainable.
        return this.each(function() {
            var $this = $(this);

            // build element specific options, compatible with Metadata Plugin
            // http://plugins.jquery.com/project/metadata
            var o = $.meta ? $.extend({}, opts, $this.data()) : opts;

            init(o, $this);
        });
    };



    /* ------------------------------------------------------

	private functions

	------------------------------------------------------ */

    function init(opts, $obj) {
        $.fn.TabSwitcherWebPart.RenderTabs(
			$.fn.TabSwitcherWebPart.RenderContainer(opts, $obj)
		);
    };



    /* ------------------------------------------------------

	define and expose public methods

	------------------------------------------------------ */

    /// <summary>
    /// adds HTML class names and renders container elements
    /// around the web part zone
    /// </summary>
    /// <param name="opts">internal options</param>
    /// <param name="$obj">jQuery object of tab switcher web part body</param>
    /// <returns>jQuery object</returns>
    $.fn.TabSwitcherWebPart.RenderContainer = function(opts, $obj) {
        var $tr, $wpz, $switcher, wrapperHtml;

        // find tab switcher web part's parent <tr> and hide it
        $tr = $obj.parents("td[id*='MSOZoneCell_WebPart']").parent().hide();

        // find the web part zone's parent <table> and set class name so we can find it later.
        $wpz = $tr.parent().parent();


        // if web part zone table already has class,
        // that means there's already a tab switcher web part in the same zone.
        if ($wpz.hasClass('tf-TabSwitcherWebPart-WebPartZone')) {
            //remove duplicate tab switcher web part
            $tr.remove();
            $('.tf-TabSwitcherWebPart-WebPart', $switcher)
				.parents("td[id*='MSOZoneCell_WebPart']").parent().remove();

            return;
        } else {
            $wpz.addClass('tf-TabSwitcherWebPart-WebPartZone');

            // create wrapper around web part zone
            wrapperHtml = '<div class="tf-Section tf-TabSwitcherWebPart'
				+ (opts.HtmlClass ? ' ' + opts.HtmlClass : '')
				+ '"><div class="tf-Section-Body"></div></div>';

            $switcher = $wpz.wrap(wrapperHtml).parent().parent();

            // remove the tab switcher web part and any duplicates
            $tr.remove();
            $('.tf-TabSwitcherWebPart-WebPart', $switcher)
				.parents("td[id*='MSOZoneCell_WebPart']").parent().remove();

            // hide all web parts except the first
            $('.tf-TabSwitcherWebPart-WebPartZone > tbody > tr:gt(0)', $switcher).hide();

            // remove vertical spacing divs between web parts
            $('.ms-PartSpacingVertical', $wpz).remove();
        }
        return $switcher;
    };


    /// <summary>renders the tab UI</summary>
    /// <param name="$switcher">jQuery object of tab switcher container element</param>
    /// <returns>void</returns>
    $.fn.TabSwitcherWebPart.RenderTabs = function($switcher) {
        // hack to detect ie6... grr...
        var isIE6 = ($.browser.msie && $.browser.version == 6);

        if ($switcher) {
            var $tabs = $('<ul class="tf-TabSwitcherWebPart-Tabs' + (isIE6 ? ' tf-TabSwitcherWebPart-Tabs-IE6' : '') + '">\n</ul>\n').prependTo($switcher);

            $('table.tf-TabSwitcherWebPart-WebPartZone > tbody > tr', $switcher).each(function(index, wp) {
                var $wp = $(wp);

                // create tabs from web part title text
                var tabLabel = $.trim($('h3.ms-WPTitle', $wp).text());

                // if web part chrome type has no title, create a tab based on index.
                var tabHtml = '<a href="javascript:void(0);">' + (tabLabel.length > 0 ? tabLabel : 'Tab ' + index) + '</a>\n';
                var $li = $('<li></li>').appendTo($tabs);
                var $tab = $(tabHtml).appendTo($li);

                // remove header from web part
                $('tr.ms-WPHeader', $wp).remove();

                // remove ms-WPBorder class from web part
                $('td', $wp).removeClass('ms-WPBorder');

                // set first tab to be selected
                if (index == 0) {
                    $tab.addClass('selected');
                }

                // add click and mouse event handlers to tab
                $tab.click(function(e) {
                    $.fn.TabSwitcherWebPart.TabClick(e, index, $(this), $switcher);
                });
            });
        }
    };


    /// <summary>tab mouse click event handler</summary>
    /// <param name="e">event object</param>
    /// <param name="index">index of tab element</param>
    /// <param name="$tab">jQuery object of tab element</param>
    /// <param name="$switcher">jQuery object of tab switcher container element</param>
    /// <returns>void</returns>
    $.fn.TabSwitcherWebPart.TabClick = function(e, index, $tab, $switcher) {
        $('.tf-TabSwitcherWebPart-Tabs a', $switcher).removeClass('selected');
        $tab.addClass('selected');

        // hide all web parts in zone and show selected one.
        $('table.tf-TabSwitcherWebPart-WebPartZone > tbody > tr:eq(' + index + ')', $switcher)
			.show().siblings().hide();
    };


    /* ------------------------------------------------------

	exposed plugin default properties or options

	------------------------------------------------------ */

    $.fn.TabSwitcherWebPart.defaults = {
        HtmlClass: null
    };


    // end of closure
})(jQuery);
